==> kubernetes-model-storageclass-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/storage/VolumeAttachmentSourceFluent.java <==
package io.fabric8.kubernetes.api.model.storage;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.PersistentVolumeSpec;

public interface VolumeAttachmentSourceFluent<A extends VolumeAttachmentSourceFluent<A>> extends Fluent<A> {


    public PersistentVolumeSpec getInlineVolumeSpec();
    public A withInlineVolumeSpec(PersistentVolumeSpec inlineVolumeSpec);
    public Boolean hasInlineVolumeSpec();
    public String getPersistentVolumeName();
    public A withPersistentVolumeName(String persistentVolumeName);
    public Boolean hasPersistentVolumeName();
    public A withNewPersistentVolumeName(StringBuilder arg1);
    public A withNewPersistentVolumeName(int[] arg1,int arg2,int arg3);
    public A withNewPersistentVolumeName(char[] arg1);
    public A withNewPersistentVolumeName(StringBuffer arg1);
    public A withNewPersistentVolumeName(byte[] arg1,int arg2);
    public A withNewPersistentVolumeName(byte[] arg1);
    public A withNewPersistentVolumeName(char[] arg1,int arg2,int arg3);
    public A withNewPersistentVolumeName(byte[] arg1,int arg2,int arg3);
    public A withNewPersistentVolumeName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPersistentVolumeName(String arg1);
}

==> kubernetes-model-storageclass-5.3.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/storage/VolumeAttachmentSourceFluent.java <==
package io.fabric8.kubernetes.api.model.storage;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.PersistentVolumeSpec;

public interface VolumeAttachmentSourceFluent<A extends VolumeAttachmentSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public PersistentVolumeSpec getInlineVolumeSpec();
    public A withInlineVolumeSpec(PersistentVolumeSpec inlineVolumeSpec);
    public Boolean hasInlineVolumeSpec();
    public String getPersistentVolumeName();
    public A withPersistentVolumeName(String persistentVolumeName);
    public Boolean hasPersistentVolumeName();
    public A withNewPersistentVolumeName(StringBuilder arg1);
    public A withNewPersistentVolumeName(int[] arg1,int arg2,int arg3);
    public A withNewPersistentVolumeName(char[] arg1);
    public A withNewPersistentVolumeName(StringBuffer arg1);
    public A withNewPersistentVolumeName(byte[] arg1,int arg2);
    public A withNewPersistentVolumeName(byte[] arg1);
    public A withNewPersistentVolumeName(char[] arg1,int arg2,int arg3);
    public A withNewPersistentVolumeName(byte[] arg1,int arg2,int arg3);
    public A withNewPersistentVolumeName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPersistentVolumeName(String arg1);
}
